# A simple reaper client, used to create a reap file

package Reaper::Client;

use Moose;
use IO::File;
use Carp;

has 'file'          => (is => 'ro', required => 1, isa => 'Str');
has 'time'          => (is => 'ro', required => 1, isa => 'Str');
has 'pid'           => (is => 'ro', required => 1, isa => 'Int');
has 'command'       => (is => 'ro', default => '', isa => 'Str');

# Create reap file
sub BUILD {
  my $self = shift;

  croak 'Invalid time ' . $self->time
    unless $self->time =~ m/^\d{1,2}:\d{2}$/;

  my $fh = IO::File->new( $self->file, 'w' )
    or croak 'Cannot open file ' . $self->file . ": $!";
  $fh->printf("%s %s %s\n", $self->time, $self->pid, $self->command)
    or croak 'Cannot write to file ' . $self->file . ": $!";
  $fh->close;

  $self;
}

1;

__END__

=head1 NAME

Reaper::Client - a simple reaper client, used to create a reap file

=head1 SYNOPSIS

    # Create a self-reap request
    $rc = Reaper::Client->new(
        file    => "/var/lib/reaper/$ME.$$",
        time    => '18:00',
        pid     => $$,
        command => $COMMAND,
    );

=head1 AUTHOR

Gavin Carr <gavin@openfusion.com.au>

=head1 COPYRIGHT

Copyright 2008 Gavin Carr.

This is free software licensed under the terms of the Perl Artistic Licence.

=cut

