use strict;
use warnings;
use FindBin;
use DateTime;
use Test::More;
use lib "$FindBin::Bin/../lib";
use Reaper::Test;

$|=1;

my $BASE = $FindBin::Bin;

plan tests => 1 + 1 * blocks;

require_ok('Reaper::Stash');

run_is input => 'expected';

sub load_set {
  my $data = shift;
  my ($now, $set) = split /\n/, $data;
  my ($hh, $mi) = split /:/, $now;
  my $now_dt = Reaper::Test->today_time($hh, $mi);
# print "now: " . $now_dt->strftime('%F %T') . "\n";
  die "bad directory $set" unless -d "$BASE/$set";
  my $stash = Reaper::Stash->new(now => $now_dt) or die "stash create failed";
  for (glob("$BASE/$set/*")) {
    $stash->add_file($_, fake => 1);
  }
  $stash->update;
  $stash->dump;
}

__END__

=== set1 16:00
--- input load_set
16:00
t01/set1
--- expected
---
kill: []
next: '17:00, 3600, /home/gavin/work/reaper/t/t01/set1/foo'
nodemap:
  /home/gavin/work/reaper/t/t01/set1/bar: '18:00, 3333'
  /home/gavin/work/reaper/t/t01/set1/baz: '18:30, 9876'
  /home/gavin/work/reaper/t/t01/set1/foo: '17:00, 1234'
now: 16:00

=== set1 17:30
--- input load_set
17:30
t01/set1
--- expected
---
kill:
  - /home/gavin/work/reaper/t/t01/set1/foo
next: '18:00, 1800, /home/gavin/work/reaper/t/t01/set1/bar'
nodemap:
  /home/gavin/work/reaper/t/t01/set1/bar: '18:00, 3333'
  /home/gavin/work/reaper/t/t01/set1/baz: '18:30, 9876'
  /home/gavin/work/reaper/t/t01/set1/foo: '17:00, 1234'
now: 17:30

=== set1 18:15
--- input load_set
18:15
t01/set1
--- expected
---
kill:
  - /home/gavin/work/reaper/t/t01/set1/foo
  - /home/gavin/work/reaper/t/t01/set1/bar
next: '18:30, 900, /home/gavin/work/reaper/t/t01/set1/baz'
nodemap:
  /home/gavin/work/reaper/t/t01/set1/bar: '18:00, 3333'
  /home/gavin/work/reaper/t/t01/set1/baz: '18:30, 9876'
  /home/gavin/work/reaper/t/t01/set1/foo: '17:00, 1234'
now: 18:15

=== set1 18:45
--- input load_set
18:45
t01/set1
--- expected
---
kill:
  - /home/gavin/work/reaper/t/t01/set1/baz
  - /home/gavin/work/reaper/t/t01/set1/foo
  - /home/gavin/work/reaper/t/t01/set1/bar
next: ''
nodemap:
  /home/gavin/work/reaper/t/t01/set1/bar: '18:00, 3333'
  /home/gavin/work/reaper/t/t01/set1/baz: '18:30, 9876'
  /home/gavin/work/reaper/t/t01/set1/foo: '17:00, 1234'
now: 18:45
